#!/bin/bash
################################################################################
# Title:    runtests.sh
# Version:  0.1
# Date:     2011-02-23
# Author:   Tim Flink <tflink@redhat.com>
# License:  GPLv2
#
# This is a quick script used to run the autoqa tests inside a virtualenv
# You will need the following packages already installed:
#   - python-virtualenv
#   - python-pip
#
# Usage:
#  runtests [-f]
################################################################################

# used for the name of the virtualenv
ENV_NAME='test_env'

# pip-python's requirements
REQ_FILE='test_dependencies.txt'

# by default, only run unit tests
RUN_FUNCTIONAL='FALSE'

# this is to make sure that pip-python isn't going to touch anything but the
# virtualenv
PIP_REQUIRE_VIRTUALENV=1

# this keeps track of the python version since virtualenv will use the system
# python version by default
PYTHON_VERSION=`python --version 2>&1 | egrep -o "2.[0-9]"`

usage()
{
    cat << EOF
    usage: $0
    This script prepares a virtualenv for running the tests (if it doesn't
    already exist) and runs unit tests in that virtualenv.

    OPTIONS:
      -h    Show this message
      -f    Run functional tests

EOF
}

# Creates and prepares a virtualenv
create_env()
{
    echo "Virtualenv ($ENV_NAME) Does not already exist."
    echo "Creating virtualenv"
    echo ""
    virtualenv $ENV_NAME

    echo "Installing packages (into $ENV_NAME) required for tests"
    echo ""
    pip-python -E $ENV_NAME install -r $REQ_FILE

    echo "Adding autoqa to virtualenv site-packages"
    pushd "$ENV_NAME/lib/python$PYTHON_VERSION/site-packages"
    ln -s "../../../../lib/autoqa/" "autoqa"
    popd

    echo "Virtualenv created and prepared."
    echo ""
}

while getopts “hf” OPTION
do
    case $OPTION  in
        h)
            usage
            exit 0
            ;;
        f)
            RUN_FUNCTIONAL='TRUE'
            ;;
    esac
done

# check for virtualenv
if [ ! -e $ENV_NAME ]
    then
        create_env
    else
        echo "Virtualenv ($ENV_NAME) detected."
fi

# activate the virtualenv
source "$ENV_NAME/bin/activate"

# run the tests
if [ $RUN_FUNCTIONAL = 'TRUE' ]
then
    py.test lib/autoqa/tests --functional
else
    py.test lib/autoqa/tests
fi

TEST_RESULT=$?

#deactivate the virtualenv
deactivate

if [ $TEST_RESULT -ne 0 ]
then
    exit 1
else
    exit 0
fi
